# urdf2mjcf

![Example](./docs/example.png)

This script converts URDF files to MJCF files, with some nice options.

## Installation

```bash
pip install urdf2mjcf
```

## Usage

### Command Line

To see all the options, use:

```bash
urdf2mjcf --help
```
